'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.desc = exports.command = undefined;

var _os = require('os');

var _os2 = _interopRequireDefault(_os);

var _split = require('split2');

var _split2 = _interopRequireDefault(_split);

var _ulid = require('ulid');

var _ulid2 = _interopRequireDefault(_ulid);

var _utilities = require('./utilities');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// @flow

var command = exports.command = 'augment';
var desc = exports.desc = 'Augments Roarr logs with additional information.';

/*:: type LogFormatterConfigurationType = {|
  +appendHostname: boolean,
  +appendInstanceId: boolean
|};*/


var createLogFormatter = function createLogFormatter(configuration /*: LogFormatterConfigurationType*/) {
  var instanceId = void 0;

  if (configuration.appendInstanceId) {
    instanceId = (0, _ulid2.default)();
  }

  var stream = (0, _split2.default)(function (line) {
    if (!(0, _utilities.isRoarrLine)(line)) {
      return '';
    }

    var message = JSON.parse(line);

    if (configuration.appendHostname) {
      message.context.hostname = _os2.default.hostname();
    }

    if (configuration.appendInstanceId) {
      message.context.instanceId = instanceId;
    }

    return JSON.stringify(message) + '\n';
  });

  return stream;
};

// eslint-disable-next-line flowtype/no-weak-types
var builder = exports.builder = function builder(yargs /*: Object*/) {
  return yargs.options({
    'append-hostname-id': {
      default: false,
      type: 'boolean'
    },
    'append-instance-id': {
      default: false,
      type: 'boolean'
    }
  });
};

// eslint-disable-next-line flowtype/no-weak-types
var handler = exports.handler = function handler(argv /*: Object*/) {
  process.stdin.pipe(createLogFormatter(argv)).pipe(process.stdout);
};
//# sourceMappingURL=augment.js.map