'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.desc = exports.command = undefined;

var _split = require('split2');

var _split2 = _interopRequireDefault(_split);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _prettyjson = require('prettyjson');

var _prettyjson2 = _interopRequireDefault(_prettyjson);

var _utilities = require('./utilities');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; } // @flow

var command = exports.command = 'pretty-print';
var desc = exports.desc = 'Format logs for user-inspection.';

var logLevelColorMap = {
  DEBUG: 'gray',
  ERROR: 'red',
  FATAL: 'red',
  INFO: 'cyan',
  TRACE: 'gray',
  WARN: 'yellow'
};

/*:: type LogFormatterConfigurationType = {|
  +includeContext: boolean
|};*/


var createLogFormatter = function createLogFormatter(configuration /*: LogFormatterConfigurationType*/) {
  var stream = (0, _split2.default)(function (line) {
    if (!(0, _utilities.isRoarrLine)(line)) {
      return line + '\n';
    }

    var message = JSON.parse(line);

    var logLevel = message.context.logLevel.toUpperCase();

    var logLevelColorName = logLevelColorMap[logLevel] || 'inverse';

    var formattedMessage = '';

    formattedMessage = '[' + new Date(message.time).toISOString() + '] ' + _chalk2.default[logLevelColorName](logLevel);

    if (message.context.package) {
      formattedMessage += ' (@' + message.context.package + ')';
    }

    if (message.context.namespace) {
      formattedMessage += ' (#' + message.context.namespace + ')';
    }

    formattedMessage += ': ' + message.message + '\n';

    if (configuration.includeContext && message.context) {
      /* eslint-disable no-unused-vars */
      var _message$context = message.context,
          tmp0 = _message$context.application,
          tmp1 = _message$context.hostname,
          tmp2 = _message$context.instanceId,
          tmp3 = _message$context.logLevel,
          tmp4 = _message$context.namespace,
          tmp5 = _message$context.package,
          tmp6 = _message$context.package,
          rest = _objectWithoutProperties(_message$context, ['application', 'hostname', 'instanceId', 'logLevel', 'namespace', 'package', 'package']);

      /* eslint-enable */

      if (Object.keys(rest).length) {
        // eslint-disable-next-line no-console
        formattedMessage += _prettyjson2.default.render(rest) + '\n\n';
      }
    }

    return formattedMessage;
  });

  return stream;
};

// eslint-disable-next-line flowtype/no-weak-types
var builder = exports.builder = function builder(yargs /*: Object*/) {
  return yargs.options({
    'include-context': {
      default: true,
      type: 'boolean'
    }
  });
};

// eslint-disable-next-line flowtype/no-weak-types
var handler = exports.handler = function handler(argv /*: Object*/) {
  process.stdin.pipe(createLogFormatter(argv)).pipe(process.stdout);
};
//# sourceMappingURL=pretty-print.js.map