'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; // @flow

var _sprintfJs = require('sprintf-js');

var _createRoarrInititialGlobalState = require('./createRoarrInititialGlobalState');

var _createRoarrInititialGlobalState2 = _interopRequireDefault(_createRoarrInititialGlobalState);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*:: import type {
  LoggerType,
  MessageContextType,
  MessageType
} from '../types';*/


global.ROARR = global.ROARR || (0, _createRoarrInititialGlobalState2.default)();

/*:: type OnMessageEventHandlerType = (message: MessageType) => void;*/


var version = '1.0.0';

var logLevels = ['trace', 'debug', 'info', 'warn', 'error', 'fatal'];

var createLogger = function createLogger(onMessage /*: OnMessageEventHandlerType*/) {
  var parentContext /*: MessageContextType*/ = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  // eslint-disable-next-line id-length
  var log /*: LoggerType*/ = function log(a, b, c, d, e, f, g, h, i, k) {
    var time = Date.now();
    var sequence = global.ROARR.sequence++;

    var context = void 0;
    var message = void 0;

    if (typeof a === 'string') {
      context = _extends({}, global.ROARR.prepend, parentContext);
      message = (0, _sprintfJs.sprintf)(a, b, c, d, e, f, g, h, i, k);
    } else {
      context = _extends({}, global.ROARR.prepend, parentContext, a);

      message = (0, _sprintfJs.sprintf)(b, c, d, e, f, g, h, i, k);
    }

    onMessage({
      context: context,
      message: message,
      sequence: sequence,
      time: time,
      version: version
    });
  };

  log.child = function (context /*: MessageContextType*/) {
    return createLogger(onMessage, _extends({}, parentContext, context));
  };

  var _loop = function _loop(logLevel) {
    log[logLevel] = function (a, b, c, d, e, f, g, h, i, k) {
      return log.child({
        logLevel: logLevel
      })(a, b, c, d, e, f, g, h, i, k);
    };
  };

  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = logLevels[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var logLevel = _step.value;

      _loop(logLevel);
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  return log;
};

exports.default = createLogger;
//# sourceMappingURL=createLogger.js.map